@@ -1,10 +1,20 @@
 #' Make Graduation Rates Part E (gender details)
 #'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#'  This section was removed by IPEDS in the 2024-2025 reporting cycle, after
+#'  being required for the 2023-2024 reporting cycle. It remains here in case it
+#'  is re-added in a future year. I have updated testing/produce code so nothing
+#'  else calls it. By making it internal, it won't be listed but remains
+#'  available.
+#'
+#'
 #' @param df A dataframe of student/degree information for unduplicated
 #'   undergraduates
 #' @param ugender A boolean: TRUE means you are collecting and able to report
 #'   "another gender" for undergraduate students, even if you have no (or few)
-#'   such students. Set as FALSE if necessary
+#'   such students. Set as FALSE if necessary. Argument deprecated from the produce function.
 #'
 #' @importFrom rlang .data
 #'
@@ -15,10 +25,14 @@
 #'
 #' @return A df aggregated for the survey part
 #' @export
+#' @keywords internal
 #'
-
+#
 make_gr_part_E <- function(df, ugender) {
 
+  lifecycle::deprecate_warn("2.9.0", "make_gr_part_E()",
+                            details = "This survey no longer collects Gender Detail information; do not use this function.")
+
   colnames(df) <- stringr::str_to_upper(colnames(df))
 
   partE <- df %>%
